@@ -64,6 +64,9 @@ def extract_media_v1(data):
     )
     media["like_count"] = media.get("like_count", 0)
     media["has_liked"] = media.get("has_liked", False)
+    media["sponsor_tags"] = [
+        tag["sponsor"] for tag in media.get("sponsor_tags", [])
+    ]
     return Media(
         caption_text=(media.get("caption") or {}).get("text", ""),
         resources=[
@@ -87,14 +90,15 @@ def extract_media_gql(data):
         media["media_type"] = 0
     if media.get("media_type") == 2 and not media.get("product_type"):
         media["product_type"] = "feed"
-    if "thumbnail_src" in media:
+    sorted_resources = sorted(
+        # display_resources - user feed, thumbnail_resources - hashtag feed
+        media.get("display_resources", media.get("thumbnail_resources", [])),
+        key=lambda o: o["config_width"] * o["config_height"],
+    )
+    if sorted_resources:
+        media["thumbnail_url"] = sorted_resources[-1]["src"]
+    elif "thumbnail_src" in media:
         media["thumbnail_url"] = media["thumbnail_src"]
-    else:
-        media["thumbnail_url"] = sorted(
-            # display_resources - user feed, thumbnail_resources - hashtag feed
-            media.get("display_resources", media.get("thumbnail_resources")),
-            key=lambda o: o["config_width"] * o["config_height"],
-        )[-1]["src"]
     if media.get("media_type") == 8:
         # remove thumbnail_url and video_url for albums
         # see resources
@@ -128,6 +132,10 @@ def extract_media_gql(data):
             extract_resource_gql(edge["node"])
             for edge in media.get("edge_sidecar_to_children", {}).get("edges", [])
         ],
+        sponsor_tags=[
+            extract_user_short(edge['node']['sponsor'])
+            for edge in media.get("edge_media_to_sponsor_user", {}).get("edges", [])
+        ],
         **media,
     )
 
@@ -180,7 +188,8 @@ def extract_user_v1(data):
     """For Private API"""
     data["external_url"] = data.get("external_url") or None
     pic_hd = data.get("hd_profile_pic_url_info") or data.get("hd_profile_pic_versions")
-    data["profile_pic_url_hd"] = pic_hd.get("url")
+    if pic_hd:
+        data["profile_pic_url_hd"] = pic_hd.get("url")
     return User(**data)
 
 
@@ -342,6 +351,9 @@ def extract_story_v1(data):
         for link in cta.get("links", []):
             story["links"].append(StoryLink(**link))
     story["user"] = extract_user_short(story.get("user"))
+    story["sponsor_tags"] = [
+        tag["sponsor"] for tag in story.get("sponsor_tags", [])
+    ]
     return Story(**story)
 
 
@@ -381,6 +393,10 @@ def extract_story_gql(data):
     story["code"] = InstagramIdCodec.encode(story["pk"])
     story["taken_at"] = story["taken_at_timestamp"]
     story["media_type"] = 2 if story["is_video"] else 1
+    story["sponsor_tags"] = [
+        extract_user_short(edge['node']['sponsor'])
+        for edge in story.get("edge_media_to_sponsor_user", {}).get("edges", [])
+    ]
     return Story(**story)
 
 
